Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(23)

Unified Diff: chromeos/network/network_util.h

Issue 289383004: Merge FavoriteState into NetworkState (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebase Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chromeos/network/network_state_handler_unittest.cc ('k') | chromeos/network/network_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chromeos/network/network_util.h
diff --git a/chromeos/network/network_util.h b/chromeos/network/network_util.h
index 0d4b8ecc95a260095da64217ba66d69c60c571ba..99707bdd817bb230de1a9a7200710eee474d4715 100644
--- a/chromeos/network/network_util.h
+++ b/chromeos/network/network_util.h
@@ -26,7 +26,7 @@ class ListValue;
namespace chromeos {
-class FavoriteState;
+class NetworkState;
class NetworkTypePattern;
// Struct for passing wifi access point data.
@@ -91,10 +91,10 @@ CHROMEOS_EXPORT std::string FormattedMacAddress(
CHROMEOS_EXPORT bool ParseCellularScanResults(
const base::ListValue& list, std::vector<CellularScanResult>* scan_results);
// Retrieves the ONC state dictionary for |favorite| using GetStateProperties.
// This includes properties from the corresponding NetworkState if it exists.
-CHROMEOS_EXPORT scoped_ptr<base::DictionaryValue> TranslateFavoriteStateToONC(
- const FavoriteState* favorite);
+CHROMEOS_EXPORT scoped_ptr<base::DictionaryValue> TranslateNetworkStateToONC(
+ const NetworkState* network);
// Retrieves the list of network services by passing |pattern|,
// |configured_only|, and |visible_only| to NetworkStateHandler::
« no previous file with comments | « chromeos/network/network_state_handler_unittest.cc ('k') | chromeos/network/network_util.cc » ('j') | no next file with comments »
@@ -91,10 +91,10 @@ CHROMEOS_EXPORT std::string FormattedMacAddress(
CHROMEOS_EXPORT bool ParseCellularScanResults(
const base::ListValue& list, std::vector<CellularScanResult>* scan_results);
-// Retrieves the ONC state dictionary for |favorite| using GetStateProperties.
+// Retrieves the ONC state dictionary for |network| using GetStateProperties.
// This includes properties from the corresponding NetworkState if it exists.

Powered by Google App Engine
This is Rietveld 408576698